from distutils.core import setup

setup(
	   name          =     'nester_k',
	   version       =     '1.2.0',
	   py_modules    =     ['nester'],
	   author        =     'll',
	   author_email  =     'll@ll.ll'
)